searchData={"items":[{"type":"module","title":"TzExtra","doc":"","ref":"TzExtra.html"},{"type":"function","title":"TzExtra.civil_time_zone_identifiers/1","doc":"","ref":"TzExtra.html#civil_time_zone_identifiers/1"},{"type":"function","title":"TzExtra.countries/0","doc":"","ref":"TzExtra.html#countries/0"},{"type":"function","title":"TzExtra.countries_time_zones/0","doc":"","ref":"TzExtra.html#countries_time_zones/0"},{"type":"function","title":"TzExtra.country_time_zone/1","doc":"","ref":"TzExtra.html#country_time_zone/1"},{"type":"function","title":"TzExtra.country_time_zone/2","doc":"","ref":"TzExtra.html#country_time_zone/2"},{"type":"function","title":"TzExtra.get_canonical_time_zone_identifier/1","doc":"","ref":"TzExtra.html#get_canonical_time_zone_identifier/1"},{"type":"function","title":"TzExtra.iana_version/0","doc":"","ref":"TzExtra.html#iana_version/0"},{"type":"function","title":"TzExtra.time_zone_identifiers/1","doc":"","ref":"TzExtra.html#time_zone_identifiers/1"},{"type":"module","title":"TzExtra.Changeset","doc":"","ref":"TzExtra.Changeset.html"},{"type":"function","title":"TzExtra.Changeset.validate_civil_time_zone_identifier/3","doc":"","ref":"TzExtra.Changeset.html#validate_civil_time_zone_identifier/3"},{"type":"function","title":"TzExtra.Changeset.validate_iso_country_code/3","doc":"","ref":"TzExtra.Changeset.html#validate_iso_country_code/3"},{"type":"function","title":"TzExtra.Changeset.validate_time_zone_identifier/3","doc":"","ref":"TzExtra.Changeset.html#validate_time_zone_identifier/3"},{"type":"module","title":"TzExtra.CountryTimeZone","doc":"","ref":"TzExtra.CountryTimeZone.html"},{"type":"function","title":"TzExtra.CountryTimeZone.for_country_code/1","doc":"","ref":"TzExtra.CountryTimeZone.html#for_country_code/1"},{"type":"function","title":"TzExtra.CountryTimeZone.for_time_zone/1","doc":"","ref":"TzExtra.CountryTimeZone.html#for_time_zone/1"},{"type":"module","title":"TzExtra.UpdatePeriodically","doc":"","ref":"TzExtra.UpdatePeriodically.html"},{"type":"function","title":"TzExtra.UpdatePeriodically.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"TzExtra.UpdatePeriodically.html#child_spec/1"},{"type":"function","title":"TzExtra.UpdatePeriodically.init/1","doc":"","ref":"TzExtra.UpdatePeriodically.html#init/1"},{"type":"function","title":"TzExtra.UpdatePeriodically.start_link/1","doc":"","ref":"TzExtra.UpdatePeriodically.html#start_link/1"},{"type":"extras","title":"TzExtra","doc":"# TzExtra\n\n`tz_extra` provides a few utilities to work with time zones. It uses [`Tz`](https://github.com/mathieuprog/tz) under the hood, which brings time zone support for Elixir.\n\n* [`TzExtra.countries_time_zones/0`](#tzextracountries_time_zones0): returns a list of time zone data by country\n* [`TzExtra.CountryTimeZone.for_country_code/1`](#tzextracountrytimezonefor_country_code1): returns a list of time zone data for a given country\n* [`TzExtra.CountryTimeZone.for_time_zone/1`](#tzextracountrytimezonefor_time_zone1): returns a list of time zone data for a time zone\n* [`TzExtra.time_zone_identifiers/1`](#tzextratime_zone_identifiers1): returns a list of time zone identifiers\n* [`TzExtra.civil_time_zone_identifiers/1`](#tzextracivil_time_zone_identifiers1): returns a list of time zone identifiers that are tied to a country\n* [`TzExtra.countries/0`](#tzextracountries0): returns a list of ISO country codes with their English name\n* [`TzExtra.get_canonical_time_zone_identifier/1`](#tzextraget_canonical_time_zone_identifier1): returns the canonical time zone identifier for the given time zone identifier\n* [`TzExtra.Changeset.validate_time_zone_identifier/3`](#tzextraChangesetvalidate_time_zone_identifier3): an Ecto Changeset validator, validating that the user input is a valid time zone\n* [`TzExtra.Changeset.validate_civil_time_zone_identifier/3`](#tzextraChangesetvalidate_civil_time_zone_identifier3): an Ecto Changeset validator, validating that the user input is a valid civil time zone\n* [`TzExtra.Changeset.validate_iso_country_code/3`](#tzextraChangesetvalidate_iso_country_code3): an Ecto Changeset validator, validating that the user input is a valid ISO country code\n\n### `TzExtra.countries_time_zones/0`\n\nReturns a list of time zone data by country. The data includes:\n* the country and time zone;\n* the current UTC and DST offsets observed;\n* the links (other city names) linking to the time zone;\n* the zone abbreviation;\n* the coordinates.\n\n#### Example\n\n```elixir\niex> TzExtra.countries_time_zones() |> Enum.at(5)\n```\n\n```elixir\n%{\n  coordinates: \"+0627+00324\",\n  country: %{code: \"AO\", name: \"Angola\", local_names: [\"Angola\"]},\n  dst_offset: 3600,\n  dst_zone_abbr: \"WAT\",\n  pretty_dst_offset: \"+01:00\",\n  pretty_utc_offset: \"+01:00\",\n  time_zone: \"Africa/Lagos\",\n  time_zone_links: [\n    \"Africa/Bangui\", \"Africa/Brazzaville\", \"Africa/Douala\",\n    \"Africa/Kinshasa\", \"Africa/Libreville\", \"Africa/Luanda\",\n    \"Africa/Malabo\", \"Africa/Niamey\", \"Africa/Porto-Novo\"\n  ],\n  utc_offset: 3600,\n  zone_abbr: \"WAT\"\n}\n```\n\nNote that a time zone may be observed by multiple countries. For example, the tz database version `2019c` lists 10\ncountries observing the time zone `Africa/Lagos`; this will result in 10 map entries for that time zone.\n\n### `TzExtra.CountryTimeZone.for_country_code/1`\n\nReturns a list of time zone data for the given country code (string or atom).\n\n### `TzExtra.CountryTimeZone.for_time_zone/1`\n\nReturns a list of time zone data for the given time zone.\n\nYou may also call `TzExtra.country_time_zone/1` which takes a country code or a time zone as argument.\n\n### `TzExtra.time_zone_identifiers/1`\n\n```elixir\niex> TzExtra.time_zone_identifiers() |> Enum.take(5)\n```\n\n```elixir\n[\n  \"Africa/Abidjan\",\n  \"Africa/Accra\",\n  \"Africa/Algiers\",\n  \"Africa/Bissau\",\n  \"Africa/Cairo\"\n]\n```\n\nThis function can take an option `:include_aliases` (by default set to `false`) to include time zone aliases. By default, only canonical time zones are returned. Set this option to `true` to include time zone aliases (also called links).\n\n### `TzExtra.civil_time_zone_identifiers/1`\n\n```elixir\niex> TzExtra.civil_time_zone_identifiers()\n```\n\nThis function returns only the time zone identifiers attached to a country. It takes two options:\n* `:include_aliases` (by default set to `false`)\n  By default, only canonical time zones are returned. Set this option to `false` to include time zone aliases (also called links).\n\n### `TzExtra.countries/0`\n\n```elixir\niex> TzExtra.countries() |> Enum.take(5)\n```\n\n```elixir\n[\n  %{code: \"AF\", name: \"Afghanistan\"},\n  %{code: \"AL\", name: \"Albania\"},\n  %{code: \"DZ\", name: \"Algeria\"},\n  %{code: \"AD\", name: \"Andorra\"},\n  %{code: \"AO\", name: \"Angola\"}\n]\n```\n\n### `TzExtra.get_canonical_time_zone_identifier/1`\n\nReturns the canonical time zone identifier for the given time zone identifier.\n\nIf you pass a canonical time zone identifier, the same identifier will be returned.\n\n```elixir\niex> TzExtra.get_canonical_time_zone_identifier(\"Asia/Phnom_Penh\")\n```\n\n```elixir\n\"Asia/Bangkok\"\n```\n\n```elixir\niex> TzExtra.get_canonical_time_zone_identifier(\"Asia/Bangkok\")\n```\n\n```elixir\n\"Asia/Bangkok\"\n```\n\n### `TzExtra.Changeset.validate_time_zone_identifier/3`\n\n```elixir\nimport TzExtra.Changeset\n\nchangeset\n|> validate_time_zone_identifier(:time_zone)\n```\n\nYou may pass the option `:allow_alias` to allow time zone aliases, as well as the `:message` option to customize the error message.\n\n### `TzExtra.Changeset.validate_civil_time_zone_identifier/3`\n\n```elixir\nimport TzExtra.Changeset\n\nchangeset\n|> validate_civil_time_zone_identifier(:time_zone)\n```\n\nYou may pass the option `:allow_alias` to allow time zone aliases, as well as the `:message` option to customize the error message.\n\n### `TzExtra.Changeset.validate_iso_country_code/3`\n\n```elixir\nimport TzExtra.Changeset\n\nchangeset\n|> validate_iso_country_code(:country_code)\n```\n\nYou may pass the `:message` option to customize the error message.","ref":"readme.html"},{"type":"extras","title":"Automatic time zone data updates - TzExtra","doc":"`tz_extra` can watch for IANA time zone database updates and automatically recompile the time zone data.\n\nTo enable automatic updates, add `TzExtra.UpdatePeriodically` as a child in your supervisor:\n\n```elixir\n{TzExtra.UpdatePeriodically, []}\n```\n\nYou may pass the option `:interval_in_days` in order to configure the frequency of the task.\n\n```elixir\n{TzExtra.UpdatePeriodically, [interval_in_days: 5]}\n```\n\n`TzExtra.UpdatePeriodically` also triggers `tz`'s time zone recompilation; so you don't need to add\n`Tz.UpdatePeriodically` if you added `TzExtra.UpdatePeriodically` in your supervisor.\n\nLastly, if you did not configure a custom http client for `tz`, add the default http client `mint` and ssl certificate store `castore` into your `mix.exs` file:\n\n```elixir\ndefp deps do\n  [\n    {:castore, \"~> 1.0\"},\n    {:mint, \"~> 1.6\"},\n    {:tz_extra, \"~> 0.30.0\"}\n  ]\nend\n```","ref":"readme.html#automatic-time-zone-data-updates"},{"type":"extras","title":"Dump JSON data for JavaScript - TzExtra","doc":"Dump time zone data into JSON files for JavaScript clients. The JSON files are written into `tz_extra`'s `priv` folder.\n\n```elixir\niex> TzExtra.JsonDumper.dump_countries_time_zones()\n```\n\n```elixir\niex> TzExtra.JsonDumper.dump_countries()\n```","ref":"readme.html#dump-json-data-for-javascript"},{"type":"extras","title":"Installation - TzExtra","doc":"Add `tz_extra` for Elixir as a dependency in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:tz_extra, \"~> 0.30.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"HexDocs - TzExtra","doc":"HexDocs documentation can be found at [https://hexdocs.pm/tz_extra](https://hexdocs.pm/tz_extra).","ref":"readme.html#hexdocs"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}